#
# spec file for package swayimg
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           swayimg
Version:        2.1
Release:        2.1
Summary:        Image viewer for Sway/Wayland
License:        MIT
URL:            https://github.com/artemsen/swayimg
Source:         https://github.com/artemsen/swayimg/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  giflib-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(OpenEXR) >= 3.1
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(libavif)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libheif)
BuildRequires:  pkgconfig(libjxl)
BuildRequires:  pkgconfig(libpng16)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(libwebpdemux)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(xkbcommon)

%description
Swayimg is a lightweight image viewer for Wayland display servers.

In a Sway compatible mode, the viewer creates an "overlay" above
the currently active window, which gives the illusion that you are
opening the image directly in a terminal window.

%prep
%autosetup

%build
%meson -Dversion=%{version}
%meson_build

%install
%meson_install

%files
%license LICENSE
%doc README.md
%{_bindir}/swayimg
%dir %{_datadir}/swayimg
%{_datadir}/swayimg/swayimgrc
%{_datadir}/applications/swayimg.desktop
%{_datadir}/bash-completion/completions/swayimg
%{_datadir}/icons/hicolor/64x64/apps/swayimg.png
%{_mandir}/man1/swayimg.1%{?ext_man}
%{_mandir}/man5/swayimgrc.5%{?ext_man}
%{_datadir}/zsh/site-functions/_swayimg

%changelog
* Mon Feb  5 2024 Jakob Lorenz <onlyjak0b@mailbox.org>
- Set version correctly
* Fri Feb  2 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.1
  * Added support for key modifiers (Ctrl/Alt/Shift);
  * Added mouse/touchpad configuration;
  * Added touchpad scrolling support;
  * Added support for mouse drag;
  * Optimized font render;
  * Removed unnecessary image reload.
* Wed Jan  3 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.0
  * Added support for multiple exec commands;
  * Added custom zoom/move step in key bindings;
  * Added support for animated PNG and AVIFS;
  * Added new scaling modes: fill, fit with and height;
  * Automatic reloading image when it changes;
  * Replaced anti-aliasing algorithm;
  * Added double buffering for output, fixed scaling glitches;
  * Added help (F1);
  * Some minor bugfix and improvements.
  * Note: the configuration file is incompatible with previous
    versions.
- Add pkgconfig(libavif) BuildRequires: Needed to build v2.0
* Tue Jul 25 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Remove ldconfig scriptlets
* Mon Jul 24 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Initial package for openSUSE
